@@ -2,7 +2,7 @@
 * file.cpp: File management
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: file.cpp,v 1.2 2001/11/27 15:33:57 bozo Exp $
+* $Id: file.cpp,v 1.3 2002/03/25 01:57:43 asmax Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -277,6 +277,17 @@ C_String C_File::GetInfo() const
 }
 
 
+//------------------------------------------------------------------------------
+// 
+//------------------------------------------------------------------------------
+// Returns the file handle
+//------------------------------------------------------------------------------
+FILE* C_File::GetHandle() const
+{
+  return m_hFd;
+}
+
+
 /*******************************************************************************
 * C_LinkedFile
 ********************************************************************************
