@@ -2,7 +2,7 @@
 * manager.cpp: Vls manager
 *-------------------------------------------------------------------------------
 * (c)1999-2001 VideoLAN
-* $Id: manager.cpp,v 1.1 2001/10/06 21:23:37 bozo Exp $
+* $Id: manager.cpp,v 1.7 2002/03/25 01:23:54 bozo Exp $
 *
 * Authors: Benoit Steiner <benny@via.ecp.fr>
 *          Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
@@ -32,9 +32,12 @@
 #include "../core/defs.h"
 
 #include "config.h"
+
 #include "../core/core.h"
+
 #include "../mpeg/mpeg.h"
 #include "../mpeg/ts.h"
+
 #include "program.h"
 #include "request.h"
 #include "admin.h"
@@ -46,7 +49,9 @@
 #include "repository.h"
 #include "directory.h"
 #include "tsstreamer.h"
+
 #include "manager.h"
+#include "vls.h"
 
 #include "repository.cpp"
 
@@ -155,8 +160,6 @@ int C_Manager::Destroy()
     DestroyPgrmTable();
     DestroyInputs();
     DestroyChannels();
-
-//    C_EventHandler::Stop();
   }
   catch(E_Exception e)
   {
@@ -236,64 +239,36 @@ void C_Manager::InitInputs()
     C_String strInputType = cCurrentInput.GetValue();
 
     // Create the input for the given source
-    try
+    C_InputModule* pModule = (C_InputModule*)
+                             C_Application::GetModuleManager()
+                                        ->GetModule("input", strInputType);
+    if(pModule)
     {
-/*      if(strInputType.ToLower() == "file")
-      {
-        // The source for the file input is provided with the vls, directly
-        // create the class
-        pInput = new C_FileInput(strInputName);
-        ASSERT(pInput);
-        pInput->SetEventHandler(this);
-      }
-      else if(strInputType.ToLower() == "dvd")
-      {
-        pInput = new C_DvdInput(strInputName);
-        ASSERT(pInput);
-        pInput->SetEventHandler(this);
-      }
-      else if(strInputType.ToLower() == "remote")
-      {
-        pInput = new C_RemoteInput(strVarName);
-        ASSERT(pInput);
-      }
-      else*/
-      {
-        // The other inputs are provided as libraries, so create the classes
-        // on the fly
-        C_String strLibName = strInputType.ToLower() + ".so";
-        C_Library<C_Input, C_String> cLib(strLibName);
-        try
-        {
-          cLib.Load();
-          pInput = cLib.CreateInstance(strInputName);
-          ASSERT(pInput);
-          pInput->SetEventHandler(this);
-        }
-        catch(E_Exception e)
-        {
-          throw E_Exception(GEN_ERR, "Unable to load library "+strLibName, e);
-        }
-      }
-    
+      pInput = pModule->NewInput(strInputName);
       ASSERT(pInput);
-      // Now init the input
+      pInput->SetEventHandler(this);
       Log(m_hLog, LOG_NOTE, "Starting input '"+strInputName+"'");
-      pInput->Init();
+      try
+      {
+        // Initialize the input
+        pInput->Init();
 
-      // And register it
-      m_cInputList.Add(strInputName, pInput);
+        // And register it
+        m_cInputList.Add(strInputName, pInput);
 
-      Log(m_hLog, LOG_NOTE, "Input '"+strInputName+"' sucessfully initialised");
-    }
-    catch(E_Exception e)
-    {
-      Log(m_hLog, LOG_ERROR, "Input '" + strInputName +
-          "' initialisation failed: " + e.Dump());
-      if(m_cInputList.Find(strInputName))
-        m_cInputList.Remove(strInputName);
-      else if(pInput)
+        Log(m_hLog, LOG_NOTE, "Input '" + strInputName +
+            "' sucessfully initialised");
+      }
+      catch(E_Exception e)
+      {
+        Log(m_hLog, LOG_ERROR, "Unable to start input '" + strInputName +
+            "': " + e.Dump());
         delete pInput;
+      }
+    }
+    else
+    {
+      Log(m_hLog, LOG_ERROR, "Input type \"" + strInputType + "\" invalid");
     }
   }
 
@@ -310,12 +285,12 @@ void C_Manager::DestroyInputs()
   // Lock the input repository
   m_cInputList.Lock();
 
-  C_RepositoryBrowser<C_String, C_Input> cIterator2 =
-                                                  m_cInputList.CreateBrowser();
+  C_RepositoryBrowser<C_String, C_Input> cIterator =
+                                                m_cInputList.CreateBrowser();
   
-  while(cIterator2.HasNextItem())
+  while(cIterator.HasNextItem())
   {
-    C_Input* pInput = cIterator2.GetNextItem();
+    C_Input* pInput = cIterator.GetNextItem();
     
     try
     {
@@ -360,31 +335,19 @@ void C_Manager::InitChannels()
     C_String strChannelName = cCurrentChannel.GetName();
     C_String strChannelType = cCurrentChannel.GetValue();
 
-    // Create the channel
-    try
+    C_ChannelModule* pModule = (C_ChannelModule*)
+                               C_Application::GetModuleManager()
+                                        ->GetModule("channel", strChannelType);
+    if(pModule)
     {
-      if(strChannelType.ToLower() == "network")
-      {
-        pChannel = new C_NetChannel(strChannelName);
-      }
-      /*else if(strChannelType.ToLower() == "file")
-      {
-        pChannel = new C_FileChannel(strChannelName);
-      }*/
-      else
-      {
-        throw E_Exception(GEN_ERR, "Skipping channel " + strChannelName +
-                          ": invalid type: " + strChannelType);
-      }
-
+      pChannel = pModule->NewChannel(strChannelName);
       ASSERT(pChannel);
       m_cChannelList.Add(strChannelName, pChannel);
       Log(m_hLog, LOG_NOTE, "Channel '"+strChannelName+"' created");
     }
-    catch(E_Exception e)
+    else
     {
-      Log(m_hLog, LOG_ERROR, "Channel '" + strChannelName +
-          "' could not be created: " + e.Dump());
+      Log(m_hLog, LOG_ERROR, "Channel type \"" + strChannelType + "\" invalid");
     }
   }
 
@@ -626,6 +589,7 @@ C_Answer C_Manager::Browse(const C_Request& cRequest)
     C_String strPgrmName = pPgrm->GetName();
     ASSERT(strPgrmName != "");
     C_Answer cPgrmDescr(strPgrmName);
+    cPgrmDescr.SetStatus(NO_ERR);
     cPgrmDescr.AddMessage(pPgrm->GetDescription());
 
     const C_Vector<C_Input>& cProviders = pPgrmInfo->GetProviders();
